@@ -29,11 +29,11 @@ from starlette.responses import Response as HttpResponse
 
 from clife_svc.libs import utils
 from clife_svc.libs.context import request_id
-from clife_svc.disconf import Disconf
-from clife_svc.configmap import ConfigMap
+from clife_svc.config.disconf import Disconf
+from clife_svc.config.configmap import ConfigMap
 from clife_svc.errors.error_code import ApiException
 from clife_svc.libs.http_request import ClientRequest
-from clife_svc.libs.log import init_conf_log, init_svc_log, klogger
+from clife_svc.libs.log import init_log, klogger, tlogger
 from clife_svc.libs.mq_handler import MQHandler
 
 
@@ -57,8 +57,12 @@ class AiServiceRoute(APIRoute):
 
             # 下面可以处理我们的响应体的报文信息，未被异常处理器拦截的请求将继续执行
             duration = time.time() - before
-            klogger.info('Request Cost: {}s'.format(round(duration, 2)))
-            klogger.info('Response Content: {}'.format(response.body.decode('utf-8')))
+            if request.scope['path'] == '/time':
+                tlogger.info('Request Cost: {}s'.format(round(duration, 2)))
+                tlogger.info('Response Content: {}'.format(response.body.decode('utf-8')))
+            else:
+                klogger.info('Request Cost: {}s'.format(round(duration, 2)))
+                klogger.info('Response Content: {}'.format(response.body.decode('utf-8')))
             return response
 
         return custom_route_handler
@@ -72,6 +76,9 @@ class App(object):
     _instance_lock = threading.Lock()
 
     def __new__(cls, *args, **kwargs):
+        """
+        实现单例模式
+        """
         if not cls._instance:
             with cls._instance_lock:
                 if not cls._instance:
@@ -92,8 +99,7 @@ class App(object):
             raise Exception('app_name can only be letters, numbers, or strike-through!')
 
         self.__app_name = app_name
-        self.__log_path = os.path.join(log_root_path, app_name)
-        init_conf_log(self.__log_path)
+        init_log(os.path.join(log_root_path, app_name), log_level='DEBUG')
 
         self.__disconf_item = Disconf('clife-ai', '0.0.1-SNAPSHOT', conf).get_disconf()
         self.__configmap = ConfigMap()
@@ -103,7 +109,6 @@ class App(object):
 
         self.__fast_api = FastAPI(title='ai-service', default_response_class=ORJSONResponse)
         self.__ai_router = APIRouter(route_class=AiServiceRoute)
-        init_svc_log(self.__log_path, log_level='DEBUG')
 
     def init_api(self) -> FastAPI:
         """
@@ -113,7 +118,7 @@ class App(object):
         self.__init_middlewares()
         self.__fast_api.add_exception_handler(ApiException, api_exception_handler)
         self.__fast_api.add_exception_handler(Exception, app_exception)
-        self.__ai_router.add_api_route('/time', endpoint=index, methods=['GET'])
+        self.__ai_router.add_api_route('/time', endpoint=index, methods=['GET'], name='time')
         self.__fast_api.include_router(self.__ai_router)
         self.__MQHandler.start_consumer()
         return self.__fast_api
@@ -141,7 +146,6 @@ class App(object):
         item = utils.get_env(key)
         if item:
             return item
-        klogger.warning('Config key not exist: {}'.format(key))
         return default
 
     def get_conf_list(self, key: str, default: list = None) -> list:
@@ -231,6 +235,19 @@ class App(object):
         """
         self.__MQHandler.send_sync(body, topic, keys, tags)
 
+    async def call_back(self, url: str, body: dict, retry=2, timeout=None):
+        """
+        推理结果回调
+        :param url:回调地址
+        :param body:回调内容，字典中必须包含‘uuid’的key，且value符合UUID规则
+        :param retry:失败重试次数，默认为2次，建议不大于3次
+        :param timeout: 回调超时时间（秒），默认为配置文件ai-commons.properties中http.timeout，目前为15秒
+        :return:回调请求响应体
+        """
+        if not re.match(r'[0-9a-f]{8}(-[0-9a-f]{4}){3}-[0-9a-f]{12}', body.get('uuid', '')):
+            raise Exception('The request body of call back must contain the correct UUID.')
+        return await self.__ClientRequest.call_back(url, body, retry, timeout)
+
 
 class Interceptor(BaseHTTPMiddleware):
     """
@@ -242,9 +259,14 @@ class Interceptor(BaseHTTPMiddleware):
         request_id.set(utils.tid_maker())
         # 记录客户端请求的URL，包括未定义的URL，
         # 拦截器中不能获取request中body内容，会导致请求阻塞
-        klogger.info('Request URL: {} {}'.format(request.method, request.url))
-        response = await call_next(request)
-        klogger.info('Response HTTP Status Code: {}'.format(response.status_code))
+        if request.scope['path'] == '/time':
+            tlogger.info('Request URL: {} {}'.format(request.method, request.url))
+            response = await call_next(request)
+            tlogger.info('Response HTTP Status Code: {}'.format(response.status_code))
+        else:
+            klogger.info('Request URL: {} {}'.format(request.method, request.url))
+            response = await call_next(request)
+            klogger.info('Response HTTP Status Code: {}'.format(response.status_code))
         return response
 
 
