@@ -18,7 +18,7 @@ from qcloud_cos import CosConfig
 from qcloud_cos import CosS3Client
 
 from clife_svc.errors.error_code import ParameterException, UploadFileException, TimeoutException
-from clife_svc.libs.log import klogger
+from clife_svc.libs.log import klogger, clogger
 
 
 class ClientRequest:
@@ -45,23 +45,23 @@ class ClientRequest:
         self.S3_BUCKET_PRIVATE = int(app.get_conf('s3.bucket.private', '0'))
         self.S3_ENDPOINT_URL = app.get_conf('s3.endpoint.url', '')
         if not all([self.S3_ACCESS_KEY, self.S3_SECRET_KEY, self.S3_BUCKET, self.S3_ENDPOINT_URL]):
-            klogger.warning('S3 Client missing required parameters, trying COS Client.')
+            clogger.warning('S3 Client missing required parameters, trying COS Client.')
             self.COS_REGION = app.get_conf('cos.region', '')
             self.COS_SECRET_ID = app.get_conf('cos.secret.id', '')
             self.COS_SECRET_KEY = app.get_conf('cos.secret.key', '')
             self.COS_BUCKET = app.get_conf('cos.bucket', '')
             self.COS_BUCKET_HOST = app.get_conf('cos.bucket.host', 'cos.clife.net')
             if not all([self.COS_REGION, self.COS_SECRET_ID, self.COS_SECRET_KEY, self.COS_BUCKET]):
-                klogger.warning('COS Client missing required parameters, upload file may disabled.')
+                clogger.warning('COS Client missing required parameters, upload file may disabled.')
             else:
                 self.S3_TYPE = 'COS'
-                klogger.info('COS Client parameters check success')
+                clogger.info('COS Client parameters check success')
         else:
             self.S3_TYPE = 'S3'
-            klogger.info('S3 Client parameters check success')
+            clogger.info('S3 Client parameters check success')
 
         if self.S3_TYPE:
-            klogger.info(f'Object Storage System: {self.S3_TYPE}')
+            clogger.info(f'Object Storage System: {self.S3_TYPE}')
 
     def create_txy_client(self):
         """
@@ -100,8 +100,8 @@ class ClientRequest:
                                                                                              await resp.text()))
 
     @staticmethod
-    async def _request_post(session, url, data, resp_type):
-        async with session.post(url, data=data) as resp:
+    async def _request_post(session, url, data, json, resp_type):
+        async with session.post(url, data=data, json=json) as resp:
             if resp.status == 200:
                 if resp_type == 'json':
                     return await resp.json()
@@ -114,8 +114,8 @@ class ClientRequest:
                     'Error of ClientRequest._request_post,resp.status:{},resp.text:{}'.format(resp.status,
                                                                                               await resp.text()))
 
-    async def _async_request(self, method, url, params=None, data=None, headers=None, cookies=None, resp_type='json',
-                             timeout=None):
+    async def _async_request(self, method, url, params=None, data=None, json=None, headers=None, cookies=None,
+                             resp_type='json', timeout=None):
         """
         http请求
         :param method:
@@ -135,7 +135,7 @@ class ClientRequest:
             if method == 'GET':
                 return await self._request_get(sess, url, params, resp_type=resp_type)
             elif method == 'POST':
-                return await self._request_post(sess, url, data, resp_type=resp_type)
+                return await self._request_post(sess, url, data, json, resp_type=resp_type)
             else:
                 raise ParameterException(data='async_request method must in [GET,POST]')
 
@@ -291,3 +291,19 @@ class ClientRequest:
                 continue
         raise UploadFileException
 
+    async def call_back(self, url: str, body: dict, retry=2, timeout=None):
+        while retry > 0:
+            retry -= 1
+            klogger.info('Start call back: UUID:{}, URL:{}, Body: {}'.format(body.get('uuid'), url, body))
+            start = time.time()
+            try:
+                resp = await self._async_request('POST', url, json=body, timeout=timeout)
+                if resp:
+                    klogger.info('Call back cost: {}s'.format(round(time.time() - start, 2)))
+                    klogger.info('Success call back.')
+                    return resp
+            except (ServerTimeoutError, asyncio.TimeoutError):
+                if retry > 0:
+                    klogger.warning('Error call back,retry left: {}'.format(retry + 1))
+                    continue
+                raise TimeoutException(data='call back timeout')
