@@ -8,26 +8,11 @@ __mtime__ = '2021/12/21'
 import os
 import datetime
 import random
-
-from clife_svc.libs.context import request_id
+import hashlib
 
 PREFIX = "CLIFE_"
 
 
-def console_log_filter(record) -> bool:
-    req_id = request_id.get()
-    record['req_id'] = req_id if req_id else tid_maker_1()
-    return True
-
-
-def svc_log_filter(record) -> bool:
-    if record['name'] in ['clife_svc.disconf', 'clife_svc.configmap']:
-        return False
-    req_id = request_id.get()
-    record['req_id'] = req_id if req_id else tid_maker_1()
-    return True
-
-
 def format_multi_value(context: str):
     """
     对多值内容进行字典转换
@@ -54,10 +39,11 @@ def get_env(name):
                 return value
 
 
-def tid_maker_1():
-    return '{0:%Y%m%d%H%M%S%f}'.format(datetime.datetime.now())
+def get_md5(string):
+    hl = hashlib.md5()
+    hl.update(string.encode(encoding='utf-8'))
+    return hl.hexdigest()
 
 
-def tid_maker_2():
-    return '{0:%Y%m%d%H%M%S%f}'.format(datetime.datetime.now()) + ''.join(
-        [str(random.randint(1, 10)) for i in range(5)])
+def tid_maker():
+    return '{0:%Y%m%d%H%M%S%f}'.format(datetime.datetime.now()) + ''.join([str(random.randint(0, 9)) for _ in range(5)])
